@@ -20,19 +20,21 @@
 
 #include "config.h"
 
+#include <gtk/gtkbuilder.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtktogglebutton.h>
-#include <glade/glade.h>
 
 #include <libtwitux/twitux-conf.h>
+#include <libtwitux/twitux-xml.h>
 #ifdef HAVE_GNOME_KEYRING
 #include <libtwitux/twitux-keyring.h>
 #endif
 
 #include "twitux.h"
 #include "twitux-account-dialog.h"
-#include "twitux-glade.h"
+
+#define XML_FILE "account_dlg.xml"
 
 typedef struct {
 	GtkWidget *dialog;
@@ -44,16 +46,16 @@ typedef struct {
 
 static void      account_response_cb          (GtkWidget         *widget,
 											   gint               response,
-											   TwituxAccount     *account);
+											   TwituxAccount     *act);
 static void      account_destroy_cb           (GtkWidget         *widget,
-											   TwituxAccount     *account);
+											   TwituxAccount     *act);
 static void      account_show_password_cb     (GtkWidget         *widget,
-											   TwituxAccount     *account);
+											   TwituxAccount     *act);
 
 static void
 account_response_cb (GtkWidget     *widget,
 					 gint           response,
-					 TwituxAccount *account)
+					 TwituxAccount *act)
 {
 	if (response == GTK_RESPONSE_OK) {
 		TwituxConf *conf;
@@ -62,91 +64,89 @@ account_response_cb (GtkWidget     *widget,
 
 		twitux_conf_set_string (conf,
 								TWITUX_PREFS_AUTH_USER_ID,
-								gtk_entry_get_text (GTK_ENTRY (account->username)));
+								gtk_entry_get_text (GTK_ENTRY (act->username)));
 
 #ifdef HAVE_GNOME_KEYRING
-		twitux_keyring_set_password (gtk_entry_get_text (GTK_ENTRY (account->username)),
-									 gtk_entry_get_text (GTK_ENTRY (account->password)));
+		twitux_keyring_set_password (gtk_entry_get_text (GTK_ENTRY (act->username)),
+									 gtk_entry_get_text (GTK_ENTRY (act->password)));
 #else
 		twitux_conf_set_string (conf,
 								TWITUX_PREFS_AUTH_PASSWORD,
-								gtk_entry_get_text (GTK_ENTRY (account->password)));
+								gtk_entry_get_text (GTK_ENTRY (act->password)));
 #endif
 
 		twitux_conf_set_bool (conf,
 							  TWITUX_PREFS_AUTH_AUTO_LOGIN,
-							  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (account->auto_login)));
+							  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (act->auto_login)));
 	}
 	gtk_widget_destroy (widget);
 }
 
 static void
 account_destroy_cb (GtkWidget     *widget,
-					TwituxAccount *account)
+					TwituxAccount *act)
 {
-	g_free (account);
+	g_free (act);
 }
 
 static void
 account_show_password_cb (GtkWidget     *widget,
-						  TwituxAccount *account)
+						  TwituxAccount *act)
 {
 	gboolean visible;
 
-	visible = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (account->show_password));
-	gtk_entry_set_visibility (GTK_ENTRY (account->password), visible);
+	visible = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (act->show_password));
+	gtk_entry_set_visibility (GTK_ENTRY (act->password), visible);
 }
 
 void
 twitux_account_dialog_show (GtkWindow *parent)
 {
-	static TwituxAccount *account;
-	GladeXML             *glade;
+	static TwituxAccount *act;
+	GtkBuilder           *ui;
 	TwituxConf           *conf;
 	gchar                *username;
 	gchar                *password;
 	gboolean              login;
 
-	if (account) {
-		gtk_window_present (GTK_WINDOW (account->dialog));
+	if (act) {
+		gtk_window_present (GTK_WINDOW (act->dialog));
 		return;
 	}
 
-	account = g_new0 (TwituxAccount, 1);
+	act = g_new0 (TwituxAccount, 1);
 
-	glade = twitux_glade_get_file ("account_dialog.glade",
-								   "account_dialog",
-								   NULL,
-								   "account_dialog", &account->dialog,
-								   "username_entry", &account->username,
-								   "password_entry", &account->password,
-								   "login_checkbutton", &account->auto_login,
-								   "show_password_checkbutton", &account->show_password,
-								   NULL);
+	/* Get widgets */
+	ui = twitux_xml_get_file (XML_FILE,
+						"account_dialog", &act->dialog,
+						"username_entry", &act->username,
+						"password_entry", &act->password,
+						"login_checkbutton", &act->auto_login,
+						"show_password_checkbutton", &act->show_password,
+						NULL);
 
-	twitux_glade_connect (glade,
-						  account,
-						  "account_dialog", "destroy", account_destroy_cb,
-						  "account_dialog", "response", account_response_cb,
-						  "show_password_checkbutton", "toggled", account_show_password_cb,
-						  NULL);
+	/* Connect the signals */
+	twitux_xml_connect (ui, act,
+						"account_dialog", "destroy", account_destroy_cb,
+						"account_dialog", "response", account_response_cb,
+						"show_password_checkbutton", "toggled", account_show_password_cb,
+						NULL);
 
-	g_object_unref (glade);
+	g_object_unref (ui);
 
-	g_object_add_weak_pointer (G_OBJECT (account->dialog), (gpointer) &account);
+	g_object_add_weak_pointer (G_OBJECT (act->dialog), (gpointer) &act);
 
-	gtk_window_set_transient_for (GTK_WINDOW (account->dialog), parent);
-
-	conf = twitux_conf_get ();
+	gtk_window_set_transient_for (GTK_WINDOW (act->dialog), parent);
 
 	/*
 	 * Check to see if the username & pasword are already in gconf,
 	 * and if so fill in the appropriate entry widget.
 	 */
+	conf = twitux_conf_get ();
 	twitux_conf_get_string (conf,
 							TWITUX_PREFS_AUTH_USER_ID,
 							&username);
-	gtk_entry_set_text (GTK_ENTRY (account->username), username ? username : "");
+	gtk_entry_set_text (GTK_ENTRY (act->username), username ? username : "");
 
 #ifdef HAVE_GNOME_KEYRING
 	/* If there is no username, don't bother searching for the password */
@@ -164,7 +164,7 @@ twitux_account_dialog_show (GtkWindow *parent)
 							&password);
 #endif
 
-	gtk_entry_set_text (GTK_ENTRY (account->password), password ? password : "");
+	gtk_entry_set_text (GTK_ENTRY (act->password), password ? password : "");
 	g_free (username);
 	g_free (password);
 
@@ -172,7 +172,8 @@ twitux_account_dialog_show (GtkWindow *parent)
 						  TWITUX_PREFS_AUTH_AUTO_LOGIN,
 						  &login);
 
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (account->auto_login), login);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (act->auto_login), login);
 
-	gtk_widget_show (account->dialog);
+	/* Ok, let's go ahead and show it */
+	gtk_widget_show (act->dialog);
 }
