@@ -20,24 +20,27 @@
 
 #include "config.h"
 
-#include <glade/glade.h>
+#include <gtk/gtkbuilder.h>
 #include <gtk/gtkdialog.h>
 
+#include <libtwitux/twitux-xml.h>
+
 #include "twitux.h"
 #include "twitux-add-dialog.h"
-#include "twitux-glade.h"
 #include "twitux-network.h"
 
+#define XML_FILE "add_friend_dlg.xml"
+
 typedef struct {
-	GtkWidget *friend_entry;
+	GtkWidget *entry;
 	GtkWidget *dialog;
 } TwituxAdd;
 
-static void      add_response_cb          (GtkWidget         *widget,
-										   gint               response,
-										   TwituxAdd         *add);
-static void      add_destroy_cb 	      (GtkWidget         *widget,
-										   TwituxAdd         *add);
+static void add_response_cb (GtkWidget *widget,
+							 gint       response,
+							 TwituxAdd *add);
+static void add_destroy_cb  (GtkWidget *widget,
+							 TwituxAdd *add);
 
 static void
 add_response_cb (GtkWidget     *widget,
@@ -45,8 +48,7 @@ add_response_cb (GtkWidget     *widget,
 				 TwituxAdd     *add)
 {
 	if (response == GTK_RESPONSE_OK) {
-		twitux_network_add_user (gtk_entry_get_text (
-									GTK_ENTRY (add->friend_entry)));
+		twitux_network_add_user (gtk_entry_get_text (GTK_ENTRY (add->entry)));
 	}
 	gtk_widget_destroy (widget);
 }
@@ -61,8 +63,8 @@ add_destroy_cb (GtkWidget     *widget,
 void
 twitux_add_dialog_show (GtkWindow *parent)
 {
-	static TwituxAdd     *add;
-	GladeXML             *glade;
+	static TwituxAdd *add;
+	GtkBuilder       *ui;
 
 	if (add) {
 		gtk_window_present (GTK_WINDOW (add->dialog));
@@ -71,24 +73,24 @@ twitux_add_dialog_show (GtkWindow *parent)
 
 	add = g_new0 (TwituxAdd, 1);
 
-	glade = twitux_glade_get_file ("add_friend_dialog.glade",
-								   "add_friend_dialog",
-								   NULL,
-								   "add_friend_dialog", &add->dialog,
-								   "frienduser_entry", &add->friend_entry,
-								   NULL);
+	/* Get widgets */
+	ui = twitux_xml_get_file (XML_FILE,
+						"add_friend_dialog", &add->dialog,
+						"frienduser_entry", &add->entry,
+						NULL);
 
-	twitux_glade_connect (glade,
-						  add,
-						  "add_friend_dialog", "destroy", add_destroy_cb,
-						  "add_friend_dialog", "response", add_response_cb,
-						  NULL);
+	/* Connect the signals */
+	twitux_xml_connect (ui, add,
+						"add_friend_dialog", "destroy", add_destroy_cb,
+						"add_friend_dialog", "response", add_response_cb,
+						NULL);
 
-	g_object_unref (glade);
+	g_object_unref (ui);
 
+	/* Set the parent */
 	g_object_add_weak_pointer (G_OBJECT (add->dialog), (gpointer) &add);
-
 	gtk_window_set_transient_for (GTK_WINDOW (add->dialog), parent);
 
+	/* Now that we're done setting up, let's show the widget */
 	gtk_widget_show (add->dialog);
 }
