@@ -1,5 +1,6 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
+ * Copyright (C) 2002-2007 Imendio AB
  * Copyright (C) 2007-2008 Brian Pepple <bpepple@fedoraproject.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -32,6 +33,7 @@
 #include <libtwitux/twitux-debug.h>
 #include <libtwitux/twitux-conf.h>
 #include <libtwitux/twitux-paths.h>
+#include <libtwitux/twitux-xml.h>
 #ifdef HAVE_GNOME_KEYRING
 #include <libtwitux/twitux-keyring.h>
 #endif
@@ -39,23 +41,24 @@
 #include "twitux.h"
 #include "twitux-about.h"
 #include "twitux-account-dialog.h"
+#include "twitux-add-dialog.h"
 #include "twitux-app.h"
 #include "twitux-geometry.h"
-#include "twitux-glade.h"
 #include "twitux-hint.h"
+#include "twitux-label.h"
 #include "twitux-network.h"
 #include "twitux-preferences.h"
 #include "twitux-send-message-dialog.h"
+#include "twitux-lists-dialog.h"
 #include "twitux-ui-utils.h"
 #include "twitux-tweet-list.h"
-#include "twitux-add-dialog.h"
-#include "twitux-label.h"
 
 #ifdef HAVE_DBUS
 #include "twitux-dbus.h"
 #endif
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TWITUX_TYPE_APP, TwituxAppPriv))
+#define GET_PRIV(obj)           \
+	(G_TYPE_INSTANCE_GET_PRIVATE ((obj), TWITUX_TYPE_APP, TwituxAppPriv))
 
 #define DEBUG_DOMAIN_SETUP       "AppSetup"
 #define DEBUG_QUIT
@@ -66,33 +69,36 @@ struct _TwituxAppPriv {
 	TwituxTweetList   *listview;
 	GtkWidget         *statusbar;
 
-	/* Widgets that are enabled when we're connected/disconnected */
+	/*
+	 * Widgets that are enabled when
+	 * we are connected/disconnected
+	 */
 	GList             *widgets_connected;
 	GList             *widgets_disconnected;
 
 	/* Timeline menu items */
-	GtkWidget         *menu_public;
-	GtkWidget         *menu_friends;
-	GtkWidget         *menu_mine;
-	GtkWidget         *menu_twitux;
-	GtkWidget         *menu_direct_messages;
-	GtkWidget         *menu_direct_replies;
+	GSList            *group;
+	GtkRadioAction    *menu_public;
+	GtkRadioAction    *menu_friends;
+	GtkRadioAction    *menu_mine;
+	GtkRadioAction    *menu_twitux;
+	GtkRadioAction    *menu_direct_messages;
+	GtkRadioAction    *menu_direct_replies;
 
-	GtkWidget         *view_friends;
+	GtkAction         *view_friends;
 
 	/* Status Icon */
 	GtkStatusIcon     *status_icon;
 
 	/* Status Icon Popup Menu */
 	GtkWidget         *popup_menu;
-	GtkWidget         *popup_menu_show_app;
+	GtkToggleAction   *popup_menu_show_app;
 
 	/* Notify */
 	NotifyNotification *notification;
 
 	/* Misc */
 	guint              size_timeout_id;
-	gboolean           friends_loaded;
 	
 	/* Expand messages widgets */
 	GtkWidget         *expand_box;
@@ -104,49 +110,52 @@ struct _TwituxAppPriv {
 static void	    twitux_app_class_init			 (TwituxAppClass        *klass);
 static void     twitux_app_init			         (TwituxApp             *app);
 static void     app_finalize                     (GObject               *object);
-static void     app_restore_main_window_geometry (GtkWidget             *main_window);
+static void     restore_main_window_geometry     (GtkWidget             *main_window);
 static void     app_setup                        (void);
-static gboolean app_main_window_quit_confirm 	 (TwituxApp             *app,
-												  GtkWidget             *window);
-static void     app_main_window_quit_confirm_cb	 (GtkWidget             *dialog,
-												  gint                   response,
+static void     main_window_destroy_cb           (GtkWidget             *window,
 												  TwituxApp             *app);
-static void     app_main_window_destroy_cb       (GtkWidget             *window,
-												  TwituxApp             *app);
-static gboolean app_main_window_delete_event_cb  (GtkWidget             *window,
+static gboolean main_window_delete_event_cb      (GtkWidget             *window,
 												  GdkEvent              *event,
 												  TwituxApp             *app);
-static void     app_twitter_connect_cb           (GtkWidget             *window,
+static void     app_set_radio_group              (TwituxApp             *app,
+												  GtkBuilder            *ui);
+static void     app_connect_cb                   (GtkWidget             *window,
 												  TwituxApp             *app);
-static void     app_twitter_disconnect_cb        (GtkWidget             *window,
+static void     app_disconnect_cb                (GtkWidget             *window,
 												  TwituxApp             *app);
-static void     app_twitter_new_msg_cb           (GtkWidget             *window,
+static void     app_new_message_cb               (GtkWidget             *window,
 												  TwituxApp             *app);
-static void     app_twitter_send_msg_cb          (GtkWidget             *window,
+static void     app_send_direct_message_cb       (GtkWidget             *window,
 												  TwituxApp             *app);
-static void     app_twitter_quit_cb              (GtkWidget             *window,
+static void     app_quit_cb                      (GtkWidget             *window,
 												  TwituxApp             *app);
-static void     app_twitter_refresh_cb           (GtkWidget             *window,
+static void     app_refresh_cb                   (GtkWidget             *window,
 												  TwituxApp             *app);
-static void     app_settings_account_cb          (GtkWidget             *window,
+static void     app_account_cb                   (GtkWidget             *window,
 												  TwituxApp             *app);
-static void     app_settings_preferences_cb       (GtkWidget             *window,
+static void     app_preferences_cb               (GtkWidget             *window,
 												  TwituxApp             *app);
-static void     app_view_public_timeline_cb      (GtkCheckMenuItem      *item,
+static void     app_public_timeline_cb           (GtkRadioAction        *action,
+												  GtkRadioAction        *current,
 												  TwituxApp             *app);
-static void     app_view_friends_timeline_cb     (GtkCheckMenuItem      *item,
+static void     app_friends_timeline_cb          (GtkRadioAction        *action,
+												  GtkRadioAction        *current,
 												  TwituxApp             *app);
-static void     app_view_my_timeline_cb          (GtkCheckMenuItem      *item,
+static void     app_mine_timeline_cb             (GtkRadioAction        *action,
+												  GtkRadioAction        *current,
 												  TwituxApp             *app);
-static void     app_view_direct_messages_cb      (GtkCheckMenuItem      *item,
+static void     app_view_direct_messages_cb      (GtkRadioAction        *action,
+												  GtkRadioAction        *current,
 												  TwituxApp             *app);
-static void     app_view_direct_replies_cb       (GtkCheckMenuItem      *item,
+static void     app_view_direct_replies_cb       (GtkRadioAction        *action,
+												  GtkRadioAction        *current,
 												  TwituxApp             *app);
-static void      app_view_twitux_timeline_cb     (GtkCheckMenuItem      *item,
+static void     app_twitux_timeline_cb           (GtkRadioAction        *action,
+												  GtkRadioAction        *current,
 												  TwituxApp             *app);
-static void     app_view_select_friends          (GtkItem               *item,
+static void     app_twitux_view_friends_cb       (GtkAction             *action,
 												  TwituxApp             *app);
-static void     app_help_about_cb                (GtkWidget             *window,
+static void     app_about_cb                     (GtkWidget             *window,
 												  TwituxApp             *app);
 static void     app_status_icon_activate_cb      (GtkStatusIcon         *status_icon,
 												  TwituxApp             *app);
@@ -154,16 +163,18 @@ static void     app_status_icon_popup_menu_cb    (GtkStatusIcon         *status_
 												  guint                  button,
 												  guint                  activate_time,
 												  TwituxApp             *app);
-static void     app_twitter_view_friend_cb       (GtkMenuItem           *menuitem,
-												  TwituxUser            *user);
-static void     app_twitter_add_friend_cb         (GtkMenuItem          *menuitem,
+static void     app_add_friend_cb                (GtkAction				*menuitem,
 												  TwituxApp             *app);
-static void     app_connection_items_setup       (GladeXML              *glade);
-static void     app_login                        (void);
+static void     app_connection_items_setup       (TwituxApp             *app,
+												  GtkBuilder            *ui);
+static void     app_login                        (TwituxApp             *app);
+static void     app_set_default_timeline         (TwituxApp             *app,
+												  gchar                 *timeline);
 static void     app_retrieve_default_timeline    (void);
 static void     app_status_icon_create_menu      (void);
 static void     app_status_icon_create           (void);
 static void     app_check_dir                    (void);
+static void     twitux_app_toggle_visibility     (void);
 static gboolean configure_event_timeout_cb       (GtkWidget             *widget);
 static gboolean app_window_configure_event_cb    (GtkWidget             *widget,
 												  GdkEventConfigure     *event,
@@ -176,7 +187,7 @@ G_DEFINE_TYPE (TwituxApp, twitux_app, G_TYPE_OBJECT);
 static void
 twitux_app_class_init (TwituxAppClass *klass)
 {
-	GObjectClass  *object_class = G_OBJECT_CLASS (klass);
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	object_class->finalize = app_finalize;
 
@@ -191,6 +202,10 @@ twitux_app_init (TwituxApp *singleton_app)
 	app = singleton_app;
 
 	priv = GET_PRIV (app);
+
+	priv->widgets_connected = NULL;
+	priv->widgets_disconnected = NULL;
+	priv->group = NULL;
 }
 
 static void
@@ -208,6 +223,7 @@ app_finalize (GObject *object)
 
 	g_list_free (priv->widgets_connected);
 	g_list_free (priv->widgets_disconnected);
+	g_slist_free (priv->group);
 
 #ifdef HAVE_DBUS
 	twitux_dbus_nm_finalize ();
@@ -219,7 +235,7 @@ app_finalize (GObject *object)
 }
 
 static void
-app_restore_main_window_geometry (GtkWidget *main_window)
+restore_main_window_geometry (GtkWidget *main_window)
 {
 	twitux_geometry_load_for_main_window (main_window);
 }
@@ -229,9 +245,10 @@ app_setup (void)
 {
 	TwituxAppPriv    *priv;
 	TwituxConf		 *conf;
-	GladeXML         *glade;
+	GtkBuilder       *ui;
 	GtkWidget        *scrolled_window;
 	GtkWidget        *expand_vbox;
+	gchar            *timeline;
 	gboolean          login;
 	gboolean		  hidden;
 
@@ -241,51 +258,66 @@ app_setup (void)
 
 	/* Set up interface */
 	twitux_debug (DEBUG_DOMAIN_SETUP, "Initialising interface");
-	glade = twitux_glade_get_file ("main_window.glade",
-								   "main_window",
-								   NULL,
-								   "main_window", &priv->window,
-								   "main_scrolledwindow", &scrolled_window,
-								   "main_statusbar", &priv->statusbar,
-								   "view_public_timeline", &priv->menu_public,
-								   "view_friends_timeline", &priv->menu_friends,
-								   "view_my_timeline", &priv->menu_mine,
-								   "view_twitux_timeline", &priv->menu_twitux,
-								   "view_direct_messages", &priv->menu_direct_messages,
-								   "view_friends", &priv->view_friends,
-								   "expand_box", &priv->expand_box,
-								   "expand_vbox", &expand_vbox,
-								   "expand_image", &priv->expand_image,
-								   "expand_title", &priv->expand_title,
-								   NULL);
+	ui = twitux_xml_get_file ("main_window.xml",
+							  "main_window", &priv->window,
+							  "main_scrolledwindow", &scrolled_window,
+							  "main_statusbar", &priv->statusbar,
+							  "view_public_timeline", &priv->menu_public,
+							  "view_friends_timeline", &priv->menu_friends,
+							  "view_my_timeline", &priv->menu_mine,
+							  "view_twitux_timeline", &priv->menu_twitux,
+							  "view_direct_messages", &priv->menu_direct_messages,
+							  "view_direct_replies", &priv->menu_direct_replies,
+							  "view_friends", &priv->view_friends,
+							  "expand_box", &priv->expand_box,
+							  "expand_vbox", &expand_vbox,
+							  "expand_image", &priv->expand_image,
+							  "expand_title", &priv->expand_title,
+							  NULL);
 
-	twitux_glade_connect (glade,
-						  app,
-						  "main_window", "destroy", app_main_window_destroy_cb,
-						  "main_window", "delete_event", app_main_window_delete_event_cb,
-						  "main_window", "configure_event", app_window_configure_event_cb,
-						  "twitter_connect", "activate", app_twitter_connect_cb,
-						  "twitter_disconnect", "activate", app_twitter_disconnect_cb,
-						  "twitter_new_message", "activate", app_twitter_new_msg_cb,
-						  "twitter_send_direct_message", "activate", app_twitter_send_msg_cb,
-						  "twitter_refresh", "activate", app_twitter_refresh_cb,
-						  "twitter_quit", "activate", app_twitter_quit_cb,
-						  "twitter_add_friend", "activate", app_twitter_add_friend_cb,
-						  "settings_account", "activate", app_settings_account_cb,
-						  "settings_preferences", "activate", app_settings_preferences_cb,
-						  "view_public_timeline", "toggled", app_view_public_timeline_cb,
-						  "view_friends_timeline", "toggled", app_view_friends_timeline_cb,
-						  "view_my_timeline", "toggled", app_view_my_timeline_cb,
-						  "view_direct_messages", "toggled", app_view_direct_messages_cb,
-						  "view_direct_replies", "toggled", app_view_direct_replies_cb,
-						  "view_twitux_timeline", "toggled", app_view_twitux_timeline_cb,
-						  "view_friends", "select", app_view_select_friends,
-						  "help_about", "activate", app_help_about_cb,
-						  NULL);
+	/* Set group for menu radio actions */
+	app_set_radio_group (app, ui);
+
+    /* Grab the conf object */
+	conf = twitux_conf_get ();
+
+	/*
+	 * Set the default timeline.  This needs
+	 * to be done before connecting signals.
+	 */
+	twitux_conf_get_string (conf,
+							TWITUX_PREFS_TWEETS_HOME_TIMELINE,
+							&timeline);
+	app_set_default_timeline (app, timeline);
+	g_free (timeline);
+
+	/* Connect the signals */
+	twitux_xml_connect (ui, app,
+						"main_window", "destroy", main_window_destroy_cb,
+						"main_window", "delete_event", main_window_delete_event_cb,
+						"main_window", "configure_event", app_window_configure_event_cb,
+						"twitter_connect", "activate", app_connect_cb,
+						"twitter_disconnect", "activate", app_disconnect_cb,
+						"twitter_new_message", "activate", app_new_message_cb,
+						"twitter_send_direct_message", "activate", app_send_direct_message_cb,
+						"twitter_refresh", "activate", app_refresh_cb,
+						"twitter_quit", "activate", app_quit_cb,
+						"twitter_add_friend", "activate", app_add_friend_cb,
+						"settings_account", "activate", app_account_cb,
+						"settings_preferences", "activate", app_preferences_cb,
+						"view_public_timeline", "changed", app_public_timeline_cb,
+						"view_friends_timeline", "changed", app_friends_timeline_cb,
+						"view_my_timeline", "changed", app_mine_timeline_cb,
+						"view_direct_messages", "changed", app_view_direct_messages_cb,
+						"view_direct_replies", "changed", app_view_direct_replies_cb,
+						"view_twitux_timeline", "changed", app_twitux_timeline_cb,
+						"view_friends", "activate", app_twitux_view_friends_cb,
+						"help_about", "activate", app_about_cb,
+						NULL);
 
 	/* Set up connected related widgets */
-	app_connection_items_setup (glade);
-	g_object_unref (glade);
+	app_connection_items_setup (app, ui);
+	g_object_unref (ui);
 
 	/* Let's hide the main window, while we are setting up the ui */
 	gtk_widget_hide (GTK_WIDGET (priv->window));
@@ -302,7 +334,7 @@ app_setup (void)
 	app_status_icon_create ();
 	
 	/* Set the main window geometry */ 	 
-	app_restore_main_window_geometry (priv->window);
+	restore_main_window_geometry (priv->window);
 
 	/* Set-up list view */
 	priv->listview = twitux_tweet_list_new ();
@@ -323,9 +355,6 @@ app_setup (void)
 
 	/* Check Twitux directory and images cache */
 	app_check_dir ();
-
-	/* Assign the conf object to a variable since we're using it more than once */
-	conf = twitux_conf_get ();
 	
 	/* Get the gconf value for whether the window should be hidden on start-up */
 	twitux_conf_get_bool (conf,
@@ -345,52 +374,11 @@ app_setup (void)
 						  &login);
 
 	if (login) 
-		app_login ();
-}
-
-static gboolean
-app_main_window_quit_confirm (TwituxApp *app,
-							  GtkWidget *window)
-{
-	TwituxAppPriv *priv;
-	GtkWidget *dialog;
-	
-	priv = GET_PRIV (app);
-	
-	dialog = gtk_message_dialog_new_with_markup	(GTK_WINDOW (twitux_app_get_window ()),
-												 0,
-												 GTK_MESSAGE_WARNING,
-												 GTK_BUTTONS_OK_CANCEL,
-												 "<b>%s</b>",
-												 _("Do you really want to quit?"));
-
-	g_signal_connect (dialog, "response",
-					  G_CALLBACK (app_main_window_quit_confirm_cb),
-					  app);
-
-	gtk_widget_show (dialog);
-
-	return TRUE;
+		app_login (app);
 }
 
 static void
-app_main_window_quit_confirm_cb (GtkWidget *dialog,
-								 gint       response,
-								 TwituxApp *app)
-{
-	TwituxAppPriv *priv;
-
-	priv = GET_PRIV (app);
-
-	gtk_widget_destroy (dialog);
-
-	if (response == GTK_RESPONSE_OK) {
-		gtk_widget_destroy (priv->window);
-	}
-}
-
-static void
-app_main_window_destroy_cb (GtkWidget *window, TwituxApp *app)
+main_window_destroy_cb (GtkWidget *window, TwituxApp *app)
 {
 	TwituxAppPriv *priv;
 
@@ -406,9 +394,9 @@ app_main_window_destroy_cb (GtkWidget *window, TwituxApp *app)
 }
 
 static gboolean
-app_main_window_delete_event_cb (GtkWidget *window,
-								 GdkEvent  *event,
-								 TwituxApp *app)
+main_window_delete_event_cb (GtkWidget *window,
+							 GdkEvent  *event,
+							 TwituxApp *app)
 {
 	TwituxAppPriv *priv;
 
@@ -425,11 +413,6 @@ app_main_window_delete_event_cb (GtkWidget *window,
 
 		return TRUE;
 	}
-
-	if (app_main_window_quit_confirm (app, window)) {
-		/* Don't quit if we have messages open */
-		return TRUE;
-	}
 	
 	if (twitux_hint_dialog_show (TWITUX_PREFS_HINTS_CLOSE_MAIN_WINDOW,
 								_("You were about to quit!"),
@@ -451,24 +434,39 @@ app_main_window_delete_event_cb (GtkWidget *window,
 	/* At this point, we have checked we have:
 	 *   - No tray
 	 *   - Have NOT shown the hint
-	 *
 	 * So we just quit.
 	 */
 
 	return FALSE;
 }
 
-gboolean
-twitux_app_is_window_visible (void)
+static void
+app_set_radio_group (TwituxApp  *app,
+					 GtkBuilder *ui)
 {
-	TwituxAppPriv *priv;
+	TwituxAppPriv  *priv;
+	GtkRadioAction *w;
+	gint            i;
+
+	const gchar     *radio_actions[] = {
+		"view_public_timeline",
+		"view_friends_timeline",
+		"view_my_timeline",
+		"view_twitux_timeline",
+		"view_direct_messages",
+		"view_direct_replies"
+	};
 
 	priv = GET_PRIV (app);
 
-	return twitux_window_get_is_visible (GTK_WINDOW (priv->window));
+	for (i = 0; i < G_N_ELEMENTS (radio_actions); i++) {
+		w = GTK_RADIO_ACTION (gtk_builder_get_object (ui, radio_actions[i]));
+		gtk_radio_action_set_group (w, priv->group);
+		priv->group = gtk_radio_action_get_group (w);
+	}
 }
 
-void
+static void
 twitux_app_toggle_visibility (void)
 {
 	TwituxAppPriv *priv;
@@ -525,23 +523,23 @@ twitux_app_set_visibility (gboolean visible)
 }
 
 static void
-app_twitter_connect_cb (GtkWidget *widget,
-						TwituxApp *app)
+app_connect_cb (GtkWidget *widget,
+				TwituxApp *app)
 {
-	app_login ();
+	app_login (app);
 }
 
 static void
-app_twitter_disconnect_cb (GtkWidget *widget,
-						   TwituxApp *app)
+app_disconnect_cb (GtkWidget *widget,
+				   TwituxApp *app)
 {
 	twitux_network_logout ();
 	twitux_app_state_on_connection (FALSE);
 }
 
 static void
-app_twitter_new_msg_cb (GtkWidget *widget,
-						TwituxApp *app)
+app_new_message_cb (GtkWidget *widget,
+					TwituxApp *app)
 {
 	TwituxAppPriv *priv;
 
@@ -552,8 +550,8 @@ app_twitter_new_msg_cb (GtkWidget *widget,
 }
 
 static void
-app_twitter_send_msg_cb (GtkWidget *widget,
-						 TwituxApp *app)
+app_send_direct_message_cb (GtkWidget *widget,
+							TwituxApp *app)
 {
 	TwituxAppPriv *priv;
 
@@ -564,8 +562,8 @@ app_twitter_send_msg_cb (GtkWidget *widget,
 }
 
 static void
-app_twitter_quit_cb (GtkWidget  *widget,
-					 TwituxApp  *app)
+app_quit_cb (GtkWidget  *widget,
+			 TwituxApp  *app)
 {
 	TwituxAppPriv *priv;
 
@@ -575,119 +573,104 @@ app_twitter_quit_cb (GtkWidget  *widget,
 }
 
 static void
-app_twitter_refresh_cb (GtkWidget *window,
-					    TwituxApp *app)
+app_refresh_cb (GtkWidget *window,
+				TwituxApp *app)
 {
 	twitux_network_refresh ();
 }
 
 static void
-app_view_public_timeline_cb (GtkCheckMenuItem *item,
-							 TwituxApp        *app)
+app_public_timeline_cb (GtkRadioAction *action,
+						GtkRadioAction *current,
+						TwituxApp      *app)
 {
-	gboolean  current;
-
-	current = gtk_check_menu_item_get_active (item);
-
-	if (!current)
-		return;
-
-	twitux_network_get_timeline (TWITUX_API_TIMELINE_PUBLIC);
-}
-
-static void
-app_view_friends_timeline_cb (GtkCheckMenuItem *item,
-							  TwituxApp        *app)
-{
-	gboolean  current;
-
-	current = gtk_check_menu_item_get_active (item);
-
-	if (!current)
-		return;
-
-	twitux_network_get_timeline (TWITUX_API_TIMELINE_FRIENDS);
-}
-
-static void
-app_view_my_timeline_cb (GtkCheckMenuItem *item,
-						 TwituxApp        *app)
-{
-	gboolean  current;
-
-	current = gtk_check_menu_item_get_active (item);
-
-	if (!current)
-		return;
-
-	twitux_network_get_user (NULL);
-}
-
-static void
-app_view_direct_messages_cb (GtkCheckMenuItem *item,
-							TwituxApp        *app)
-{
-	gboolean  current;
-
-	current = gtk_check_menu_item_get_active (item);
-
-	if (!current)
-		return;
-
-	twitux_network_get_timeline (TWITUX_API_DIRECT_MESSAGES);
-}
-
-static void
-app_view_direct_replies_cb (GtkCheckMenuItem *item,
-							TwituxApp        *app)
-{
-	gboolean  current;
-
-	current = gtk_check_menu_item_get_active (item);
-
-	if (!current)
-		return;
-
-	twitux_network_get_timeline (TWITUX_API_REPLIES);
-}
-
-static void
-app_view_twitux_timeline_cb (GtkCheckMenuItem *item, 	 
-	                         TwituxApp        *app) 	 
-{ 	 
-	gboolean  current;
-
-	current = gtk_check_menu_item_get_active (item);
-	  	 
-	if (!current)
-		return;
-	  	 
-	twitux_network_get_timeline (TWITUX_API_TIMELINE_TWITUX); 	 
-}
-
-static void
-app_view_select_friends (GtkItem *item,
-						 TwituxApp *app)
-{
-	GList *friends;
-
 	TwituxAppPriv *priv;
 
 	priv = GET_PRIV (app);
 
-	if (priv->friends_loaded)
-		return;
-
-	friends = twitux_network_get_friends ();
-	
-	if (friends) {
-		twitux_app_set_friends (friends);
-	}
+	if (priv->menu_public == current)
+		twitux_network_get_timeline (TWITUX_API_TIMELINE_PUBLIC);
 }
 
 static void
-app_settings_account_cb (GtkWidget *widget,
-						 TwituxApp *app)
+app_friends_timeline_cb (GtkRadioAction *action,
+						 GtkRadioAction *current,
+						 TwituxApp      *app)
+{
+	TwituxAppPriv *priv;
+
+	priv = GET_PRIV (app);
+
+	if (priv->menu_friends == current) 
+		twitux_network_get_timeline (TWITUX_API_TIMELINE_FRIENDS);
+}
+
+static void
+app_mine_timeline_cb (GtkRadioAction *action,
+					  GtkRadioAction *current,
+					  TwituxApp      *app)
+{
+	TwituxAppPriv *priv;
+
+	priv = GET_PRIV (app);
+
+	if (priv->menu_mine == current)
+		twitux_network_get_user (NULL);
+}
+
+static void
+app_view_direct_messages_cb (GtkRadioAction *action,
+							 GtkRadioAction *current,
+							 TwituxApp      *app)
+{
+	TwituxAppPriv *priv;
+
+	priv = GET_PRIV (app);
+
+	if (priv->menu_direct_messages == current)
+		twitux_network_get_timeline (TWITUX_API_DIRECT_MESSAGES);
+}
+
+static void
+app_view_direct_replies_cb (GtkRadioAction *action,
+							GtkRadioAction *current,
+							TwituxApp      *app)
+{
+	TwituxAppPriv *priv;
+
+	priv = GET_PRIV (app);
+
+	if (priv->menu_direct_replies == current) 
+		twitux_network_get_timeline (TWITUX_API_REPLIES);
+}
+
+static void
+app_twitux_timeline_cb (GtkRadioAction *action, 	 
+						GtkRadioAction *current,
+						TwituxApp      *app)
+{
+	TwituxAppPriv *priv;
+
+	priv = GET_PRIV (app);
+
+	if (priv->menu_twitux == current)
+		twitux_network_get_timeline (TWITUX_API_TIMELINE_TWITUX);
+}
+
+static void
+app_twitux_view_friends_cb (GtkAction *action,
+							TwituxApp *app)
+{
+	TwituxAppPriv *priv;
+
+	priv = GET_PRIV (app);
+
+	twitux_lists_dialog_show (GTK_WINDOW (priv->window));
+}
+
+static void
+app_account_cb (GtkWidget *widget,
+				TwituxApp *app)
 {
 	TwituxAppPriv *priv;
 
@@ -697,8 +680,8 @@ app_settings_account_cb (GtkWidget *widget,
 }
 
 static void
-app_settings_preferences_cb (GtkWidget *widget,
-							 TwituxApp *app)
+app_preferences_cb (GtkWidget *widget,
+					TwituxApp *app)
 {
 	TwituxAppPriv *priv;
 
@@ -708,8 +691,8 @@ app_settings_preferences_cb (GtkWidget *widget,
 }
 
 static void
-app_help_about_cb (GtkWidget *widget,
-				   TwituxApp *app)
+app_about_cb (GtkWidget *widget,
+			  TwituxApp *app)
 {
 	TwituxAppPriv *priv;
 
@@ -719,8 +702,8 @@ app_help_about_cb (GtkWidget *widget,
 }
 
 static void
-app_twitter_add_friend_cb (GtkMenuItem *menuitem,
-						   TwituxApp *app)
+app_add_friend_cb (GtkAction *item,
+				   TwituxApp *app)
 {
 	TwituxAppPriv *priv;
 
@@ -758,8 +741,9 @@ app_status_icon_popup_menu_cb (GtkStatusIcon *status_icon,
 
 	g_signal_handlers_block_by_func (priv->popup_menu_show_app,
 									 app_show_hide_cb, app);
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (priv->popup_menu_show_app),
-									show);
+
+	gtk_toggle_action_set_active (priv->popup_menu_show_app, show);
+
 	g_signal_handlers_unblock_by_func (priv->popup_menu_show_app,
 									   app_show_hide_cb, app);
 
@@ -775,28 +759,25 @@ static void
 app_status_icon_create_menu (void)
 {
 	TwituxAppPriv *priv;
-	GladeXML      *glade;
+	GtkBuilder    *ui;
 
 	priv = GET_PRIV (app);
 
-	glade = twitux_glade_get_file ("tray_menu.glade",
-								   "tray_menu",
-								   NULL,
-								   "tray_menu", &priv->popup_menu,
-								   "tray_show_app", &priv->popup_menu_show_app,
-								   NULL);
+	/* Get widgets */
+	ui =
+		twitux_xml_get_file ("tray_menu.xml",
+							 "tray_menu", &priv->popup_menu,
+							 "tray_show_app", &priv->popup_menu_show_app,
+							 NULL);
 
-	twitux_glade_connect (glade,
-						  app,
-						  "tray_new_message", "activate", app_twitter_new_msg_cb,
-						  "tray_quit", "activate", app_twitter_quit_cb,
-						  NULL);
+	/* Connect the signals */
+	twitux_xml_connect (ui, app,
+						"tray_new_message", "activate", app_new_message_cb,
+						"tray_quit", "activate", app_quit_cb,
+						"tray_show_app", "toggled", app_show_hide_cb,
+						NULL);
 
-	g_signal_connect (priv->popup_menu_show_app,
-					  "toggled",
-					  G_CALLBACK (app_show_hide_cb), app);
-
-	g_object_unref (glade);
+	g_object_unref (ui);
 }
 
 static void
@@ -867,22 +848,16 @@ app_window_configure_event_cb (GtkWidget         *widget,
 		g_source_remove (priv->size_timeout_id);
 	}
 
-	priv->size_timeout_id = g_timeout_add (500,
-										   (GSourceFunc) configure_event_timeout_cb,
-										   widget);
+	priv->size_timeout_id =
+		g_timeout_add (500,
+					   (GSourceFunc) configure_event_timeout_cb,
+					   widget);
 
 	return FALSE;
 }
 
 static void
-app_twitter_view_friend_cb (GtkMenuItem *menuitem,
-							TwituxUser *user)
-{
-	twitux_network_get_user (user->screen_name);
-}
-
-static void
-app_login (void)
+app_login (TwituxApp *a)
 {
 	TwituxAppPriv *priv;
 	TwituxConf    *conf;
@@ -901,7 +876,7 @@ app_login (void)
 	}
 #endif
 	
-	priv = GET_PRIV (app);
+	priv = GET_PRIV (a);
 
 	conf = twitux_conf_get ();
 	twitux_conf_get_string (conf,
@@ -929,12 +904,42 @@ app_login (void)
 		app_retrieve_default_timeline ();
 	}
 
-	priv->friends_loaded = FALSE;
-
 	g_free (username);
 	g_free (password);
 }
 
+/*
+ * Function to set the default
+ * timeline in the menu.
+ */
+static void
+app_set_default_timeline (TwituxApp *app, gchar *timeline)
+{
+	TwituxAppPriv *priv;
+
+	priv = GET_PRIV (app);
+
+	/* This shouldn't happen, but just in case */
+	if (G_STR_EMPTY (timeline)) {
+		g_warning ("Default timeline in not set");
+		return;
+	}
+
+	if (strcmp (timeline, TWITUX_API_TIMELINE_FRIENDS) == 0) {
+		gtk_radio_action_set_current_value (priv->menu_friends,	1);
+	} else if (strcmp (timeline, TWITUX_API_TIMELINE_PUBLIC) == 0) {
+		gtk_radio_action_set_current_value (priv->menu_public, 1);
+	} else if (strcmp (timeline, TWITUX_API_TIMELINE_MY) == 0) {
+		gtk_radio_action_set_current_value (priv->menu_mine, 1);
+	} else if (strcmp (timeline, TWITUX_API_TIMELINE_TWITUX) == 0) {
+		gtk_radio_action_set_current_value (priv->menu_twitux, 1);
+	} else {
+		/* Let's fallback to friends timeline */
+		gtk_radio_action_set_current_value (priv->menu_friends,	1);
+	}
+}
+
+/* Function to retrieve the users default timeline */
 static void
 app_retrieve_default_timeline (void)
 {
@@ -947,32 +952,12 @@ app_retrieve_default_timeline (void)
 							TWITUX_PREFS_TWEETS_HOME_TIMELINE,
 							&timeline);
 
-	/* This shouldn't happen, but just in case */
-	if (G_STR_EMPTY (timeline)) {
-		g_warning ("Default timeline in not set");
+	if (G_STR_EMPTY (timeline)){
 		timeline = g_strdup (TWITUX_API_TIMELINE_FRIENDS);
-	}
-
-	if (strcmp (timeline, TWITUX_API_TIMELINE_FRIENDS) == 0) {
-		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (priv->menu_friends),
-										TRUE);
-	} else if (strcmp (timeline, TWITUX_API_TIMELINE_PUBLIC) == 0) {
-		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (priv->menu_public),
-										TRUE);
-	} else if (strcmp (timeline, TWITUX_API_TIMELINE_MY) == 0) {
-		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (priv->menu_mine),
-										TRUE);
-	} else if (strcmp (timeline, TWITUX_API_TIMELINE_TWITUX) == 0) {
-		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (priv->menu_twitux),
-										TRUE);
-	} else {
-		/* Let's fallback to friends timeline */
-		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (priv->menu_friends),
-										TRUE);
+		app_set_default_timeline (app, TWITUX_API_TIMELINE_FRIENDS);
 	}
 
 	twitux_network_get_timeline (timeline);
-  
 	g_free (timeline);
 }
 
@@ -992,9 +977,13 @@ app_check_dir (void)
 }
 
 static void
-app_connection_items_setup (GladeXML *glade)
+app_connection_items_setup (TwituxApp  *app,
+							GtkBuilder *ui)
 {
 	TwituxAppPriv *priv;
+	GList         *list;
+	GObject       *w;
+	gint           i;
 
 	const gchar   *widgets_connected[] = {
 		"twitter_disconnect",
@@ -1009,31 +998,25 @@ app_connection_items_setup (GladeXML *glade)
 		"twitter_connect"
 	};
 
-	GList         *list;
-	GtkWidget     *w;
-	gint           i;
-
 	priv = GET_PRIV (app);
 
 	for (i = 0, list = NULL; i < G_N_ELEMENTS (widgets_connected); i++) {
-		w = glade_xml_get_widget (glade, widgets_connected[i]);
+		w = gtk_builder_get_object (ui, widgets_connected[i]);
 		list = g_list_prepend (list, w);
 	}
 
 	priv->widgets_connected = list;
 
 	for (i = 0, list = NULL; i < G_N_ELEMENTS (widgets_disconnected); i++) {
-		w = glade_xml_get_widget (glade, widgets_disconnected[i]);
+		w = gtk_builder_get_object (ui, widgets_disconnected[i]);
 		list = g_list_prepend (list, w);
 	}
 
 	priv->widgets_disconnected = list;
 }
 
-
-
 void
-twitux_app_state_on_connection (gboolean   connected)
+twitux_app_state_on_connection (gboolean connected)
 {
 	TwituxAppPriv *priv;
 	GList         *l;
@@ -1041,11 +1024,11 @@ twitux_app_state_on_connection (gboolean   connected)
 	priv = GET_PRIV (app);
 
 	for (l = priv->widgets_connected; l; l = l->next) {
-		gtk_widget_set_sensitive (l->data, connected);
+		g_object_set (l->data, "sensitive", connected, NULL);
 	}
 
 	for (l = priv->widgets_disconnected; l; l = l->next) {
-		gtk_widget_set_sensitive (l->data, !connected);
+		g_object_set (l->data, "sensitive", !connected, NULL);
 	}
 }
 
@@ -1075,73 +1058,13 @@ twitux_app_set_statusbar_msg (gchar *message)
 	gtk_statusbar_push (GTK_STATUSBAR (priv->statusbar), 1, message);
 }
 
-void
-twitux_app_set_friends (GList *friends)
-{
-	TwituxAppPriv *priv;
-	GtkWidget     *menu;
-	GtkWidget     *item;
-	GList         *list;
-	TwituxUser    *user;
-
-	priv = GET_PRIV (app);
-
-	/* Check if we have a menu */
-	menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (priv->view_friends));
-	if (menu) {
-		/* Delete previous items */
-		gtk_container_foreach (GTK_CONTAINER (menu),
-							   (GtkCallback)gtk_widget_destroy, NULL);
-	} else {
-		/* New menu */
-		menu = gtk_menu_new ();
-	}
-
-	if (!friends) {
-		/* Temp. menu */
-		priv->friends_loaded = FALSE;
-		item = gtk_menu_item_new_with_label (_("Fetching friends..."));
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-		gtk_widget_show (item);
-	} else {
-		/* Load friends menu from list */
-		priv->friends_loaded = TRUE;
-		for (list = friends; list; list = list->next) {
-			user = (TwituxUser *)list->data;
-			twitux_app_add_friend (user);
-		}
-	}
-
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (priv->view_friends), menu);
-}
-
-void
-twitux_app_add_friend (TwituxUser *user)
-{
-	TwituxAppPriv *priv;
-	GtkWidget	  *menu;
-	GtkWidget	  *item;
-
-	priv = GET_PRIV (app);
-
-	menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (priv->view_friends));
-
-	if (menu) {
-		item = gtk_menu_item_new_with_label (user->name);
-		g_signal_connect (item, "activate",
-						  G_CALLBACK (app_twitter_view_friend_cb), user);
-		gtk_widget_show (item);
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-	}
-}
-
 void
 twitux_app_show_notification (gint tweets)
 {
 	TwituxAppPriv	*priv;
 	gchar			*msg;
 	gchar			*s;
-	gboolean		notify;
+	gboolean		 notify;
 
 	priv = GET_PRIV (app);
 
@@ -1171,7 +1094,7 @@ twitux_app_show_notification (gint tweets)
 												  NULL,
 												  priv->status_icon);
 
-	g_object_set(priv->notification, "icon-name", "twitux", NULL) ;
+	g_object_set(priv->notification, "icon-name", "twitux", NULL);
 
 	notify_notification_set_timeout (priv->notification, 3000);
 	notify_notification_show (priv->notification, NULL);
@@ -1181,7 +1104,7 @@ twitux_app_show_notification (gint tweets)
 
 void
 twitux_app_set_image (const gchar *file,
-                      GtkTreeIter iter)
+                      GtkTreeIter  iter)
 {
 	GtkListStore *store;
 	GdkPixbuf	 *pixbuf;
