@@ -38,6 +38,7 @@
 #include "twitux-parser.h"
 #include "twitux-app.h"
 #include "twitux-send-message-dialog.h"
+#include "twitux-lists-dialog.h"
 
 #define DEBUG_DOMAIN	  "Network"
 #define TWITUX_HEADER_URL "http://twitux.sourceforge.net/client.xml"
@@ -639,7 +640,6 @@ network_cb_on_login (SoupSession *session,
 
 	if (network_check_http (msg->status_code)) {
 		twitux_app_state_on_connection (TRUE);
-		twitux_app_set_friends (NULL);
 		return;
 	}
 
@@ -761,11 +761,11 @@ network_cb_on_users (SoupSession *session,
 
 	/* check if it ok, and if it is a followers or following list */
 	if (users && friends){
-		/* Friends timeline retrived */
+		/* Friends retrived */
 		user_friends = users;
-		twitux_app_set_friends (users);
+		twitux_lists_dialog_load_lists (user_friends);
 	} else if (users){
-		/* Followers lisy retrived */
+		/* Followers list retrived */
 		user_followers = users;
 		twitux_message_set_followers (user_followers);
 	} else {
@@ -833,7 +833,6 @@ network_cb_on_add (SoupSession *session,
 	if (user) {
 		user_friends = g_list_append ( user_friends, user );
 		twitux_app_set_statusbar_msg (_("Friend Added"));
-		twitux_app_add_friend (user);
 	} else {
 		twitux_app_set_statusbar_msg (_("Failed to add user"));
 	}
