@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
  * Copyright (C) 2003-2007 Imendio AB
- * Copyright (C) 2007 Brian Pepple
+ * Copyright (C) 2007-2008 Brian Pepple
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,6 +22,7 @@
  *          Richard Hult <richard@imendio.com>
  *          Martyn Russell <martyn@imendio.com>
  *			Brian Pepple <bpepple@fedoraproject.org>
+ *			Daniel Morales <daniminas@gmail.com>
  */
 
 #include "config.h"
@@ -29,16 +30,17 @@
 #include <string.h>
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <glib/gi18n.h>
 
 #include <libtwitux/twitux-conf.h>
+#include <libtwitux/twitux-xml.h>
 
 #include "twitux.h"
-#include "twitux-glade.h"
 #include "twitux-preferences.h"
 #include "twitux-spell.h"
 
+#define XML_FILE "prefs_dlg.xml"
+
 typedef struct {
 	GtkWidget *dialog;
 	GtkWidget *notebook;
@@ -812,7 +814,7 @@ void
 twitux_preferences_dialog_show (GtkWindow *parent)
 {
 	static TwituxPrefs *prefs;
-	GladeXML           *glade;
+	GtkBuilder         *ui;
 
 	if (prefs) {
 		gtk_window_present (GTK_WINDOW (prefs->dialog));
@@ -821,30 +823,31 @@ twitux_preferences_dialog_show (GtkWindow *parent)
 
 	prefs = g_new0 (TwituxPrefs, 1);
 
-	glade = twitux_glade_get_file ("preferences_dialog.glade",
-								   "preferences_dialog",
-								   NULL,
-								   "preferences_dialog", &prefs->dialog,
-								   "preferences_notebook", &prefs->notebook,
-								   "combobox_timeline", &prefs->combo_default_timeline,
-								   "combobox_reload", &prefs->combo_reload,
-								   "expand_checkbutton", &prefs->expand,
-								   "notify_checkbutton", &prefs->notify,
-								   "names_checkbutton", &prefs->names,
-								   "spell_checkbutton", &prefs->spell,
-								   "spell_treeview", &prefs->treeview_spell_checker,
-								   NULL);
+	/* Get widgets */
+	ui = twitux_xml_get_file (XML_FILE,
+						"preferences_dialog", &prefs->dialog,
+						"preferences_notebook", &prefs->notebook,
+						"combobox_timeline", &prefs->combo_default_timeline,
+						"combobox_reload", &prefs->combo_reload,
+						"expand_checkbutton", &prefs->expand,
+						"notify_checkbutton", &prefs->notify,
+						"names_checkbutton", &prefs->names,
+						"spell_checkbutton", &prefs->spell,
+						"spell_treeview", &prefs->treeview_spell_checker,
+						NULL);
 
-	twitux_glade_connect (glade,
-						  prefs,
-						  "preferences_dialog", "destroy", preferences_destroy_cb,
-						  "preferences_dialog", "response", preferences_response_cb,
-						  NULL);
+	/* Connect the signals */
+	twitux_xml_connect (ui, prefs,
+						"preferences_dialog", "destroy", preferences_destroy_cb,
+						"preferences_dialog", "response", preferences_response_cb,
+						NULL);
 
-	g_object_unref (glade);
+	g_object_unref (ui);
 
 	g_object_add_weak_pointer (G_OBJECT (prefs->dialog), (gpointer) &prefs);
+	gtk_window_set_transient_for (GTK_WINDOW (prefs->dialog), parent);
 
+	/* Set up the rest of the widget */
 	preferences_timeline_setup (prefs);
 	preferences_reload_setup (prefs);
 
@@ -854,6 +857,7 @@ twitux_preferences_dialog_show (GtkWindow *parent)
 	preferences_languages_add (prefs);
 	preferences_languages_load (prefs);
 
+	/* If compiled with spelling support, show the notebook page */
 	if (twitux_spell_supported ()) {
 		GtkWidget *page;
 
@@ -861,7 +865,5 @@ twitux_preferences_dialog_show (GtkWindow *parent)
 		gtk_widget_show (page);
 	}
 
-	gtk_window_set_transient_for (GTK_WINDOW (prefs->dialog), parent);
-
 	gtk_widget_show (prefs->dialog);
 }
