@@ -1,5 +1,6 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
+ * Copyright (C) 2002-2007 Imendio AB
  * Copyright (C) 2007-2008 Brian Pepple <bpepple@fedoraproject.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -17,34 +18,40 @@
  * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  * 
- * Authors: Brian Pepple <bpepple@fedoraproject.org>
- *			Daniel Morales <daniminas@gmail.com>
+ * Authors: Mikael Hallendal <micke@imendio.com>
+ *          Richard Hult <richard@imendio.com>
+ *          Martyn Russell <martyn@imendio.com>
+ *          Geert-Jan Van den Bogaerde <geertjan@gnome.org>
+ *          Brian Pepple <bpepple@fedoraproject.org>
+ *          Daniel Morales <daniminas@gmail.com>
  */
 
 #include "config.h"
 
 #include <string.h>
+
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
-#include <glade/glade.h>
+#include <gtk/gtktextiter.h>
+#include <gtk/gtkwidget.h>
 
 #include <libtwitux/twitux-conf.h>
 #include <libtwitux/twitux-debug.h>
+#include <libtwitux/twitux-xml.h>
 
 #include "twitux.h"
 #include "twitux-send-message-dialog.h"
 #include "twitux-spell.h"
 #include "twitux-spell-dialog.h"
-#include "twitux-glade.h"
 #include "twitux-network.h"
 
 #define DEBUG_DOMAIN_SETUP    "SendMessage"
-#define DEBUG_QUIT
+#define XML_FILE              "send_message_dlg.xml"
 
 /* Let's use the preferred maximum character count */
 #define MAX_CHARACTER_COUNT 140
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TWITUX_TYPE_MESSAGE, TwituxMsgDialogPriv))
+#define GET_PRIV(obj)          \
+	(G_TYPE_INSTANCE_GET_PRIVATE ((obj), TWITUX_TYPE_MESSAGE, TwituxMsgDialogPriv))
 
 typedef struct {
 	GtkWidget         *textview;
@@ -70,25 +77,25 @@ static void	twitux_message_class_init		     (TwituxMsgDialogClass *klass);
 static void twitux_message_init			         (TwituxMsgDialog      *dialog);
 static void message_finalize                     (GObject              *object);
 static void message_setup                        (GtkWindow            *parent);
-static void message_set_characters_available    (GtkTextBuffer         *buffer,
-												 TwituxMsgDialog       *dialog);
-static void message_text_buffer_changed_cb      (GtkTextBuffer         *buffer,
-											     TwituxMsgDialog       *dialog);
-static void message_text_populate_popup_cb      (GtkTextView           *view,
-												 GtkMenu               *menu,
-												 TwituxMsgDialog       *dialog);
-static void message_text_check_word_spelling_cb (GtkMenuItem           *menuitem,
-												 TwituxMessageSpell    *message_spell);
-static TwituxMessageSpell *message_spell_new    (GtkWidget             *window,
-											     const gchar           *word,
-											     GtkTextIter            start,
-											     GtkTextIter            end);
-static void message_spell_free                  (TwituxMessageSpell    *message_spell);
-static void message_destroy_cb                  (GtkWidget             *widget,
-											     TwituxMsgDialog       *dialog);
-static void message_response_cb                 (GtkWidget             *widget,
-											     gint                   response,
-											     TwituxMsgDialog       *dialog);
+static void message_set_characters_available     (GtkTextBuffer        *buffer,
+												  TwituxMsgDialog      *dialog);
+static void message_text_buffer_changed_cb       (GtkTextBuffer        *buffer,
+											      TwituxMsgDialog      *dialog);
+static void message_text_populate_popup_cb       (GtkTextView          *view,
+												  GtkMenu              *menu,
+												  TwituxMsgDialog      *dialog);
+static void message_text_check_word_spelling_cb  (GtkMenuItem          *menuitem,
+												  TwituxMessageSpell   *message_spell);
+static TwituxMessageSpell *message_spell_new     (GtkWidget            *window,
+												  const gchar          *word,
+												  GtkTextIter           start,
+												  GtkTextIter           end);
+static void message_spell_free                   (TwituxMessageSpell   *message_spell);
+static void message_destroy_cb                   (GtkWidget            *widget,
+												  TwituxMsgDialog      *dialog);
+static void message_response_cb                  (GtkWidget            *widget,
+												  gint                  response,
+												  TwituxMsgDialog      *dialog);
 
 static TwituxMsgDialog  *dialog = NULL;
 
@@ -120,37 +127,37 @@ static void
 message_setup (GtkWindow  *parent)
 {
 	TwituxMsgDialogPriv   *priv;
-	GladeXML         	  *glade;
+	GtkBuilder            *ui;
 	GtkTextBuffer         *buffer;
 	const gchar           *standard_msg;
 	gchar                 *character_count;
-	GtkCellRenderer		  *renderer;
+	GtkCellRenderer       *renderer;
 	GtkListStore          *model_followers;
 	
 	priv = GET_PRIV (dialog);
 
 	/* Set up interface */
 	twitux_debug (DEBUG_DOMAIN_SETUP, "Initialising message dialog");
-	glade = twitux_glade_get_file ("send_message_dialog.glade",
-								   "send_message_dialog",
-								   NULL,
-								   "send_message_dialog", &priv->dialog,
-								   "send_message_textview", &priv->textview,
-								   "char_label", &priv->label,
-								   "friends_combo", &priv->friends_combo,
-								   "friends_label", &priv->friends_label,
-								   "send_button", &priv->send_button,
-								   NULL);
 
-	twitux_glade_connect (glade,
-						  dialog,
-						  "send_message_dialog", "destroy", message_destroy_cb,
-						  "send_message_dialog", "response", message_response_cb,
-						  "send_message_textview", "populate_popup", message_text_populate_popup_cb,
-						  NULL);
+	/* Get widgets */
+	ui =
+		twitux_xml_get_file (XML_FILE,
+							 "send_message_dialog", &priv->dialog,
+							 "send_message_textview", &priv->textview,
+							 "char_label", &priv->label,
+							 "friends_combo", &priv->friends_combo,
+							 "friends_label", &priv->friends_label,
+							 "send_button", &priv->send_button,
+							 NULL);
+	
+	/* Connect the signals */
+	twitux_xml_connect (ui, dialog,
+						"send_message_dialog", "destroy", message_destroy_cb,
+						"send_message_dialog", "response", message_response_cb,
+						"send_message_textview", "populate_popup", message_text_populate_popup_cb,
+						NULL);
 
-	/* Set up connected related widgets */
-	g_object_unref (glade);
+	g_object_unref (ui);
 
 	/* Set the label */
 	standard_msg = _("Characters Available");
@@ -235,14 +242,15 @@ twitux_message_set_followers (GList *followers)
 
 	priv = GET_PRIV (dialog);
 
-	model_followers = GTK_LIST_STORE (
-						gtk_combo_box_get_model (
+	model_followers =
+		GTK_LIST_STORE (gtk_combo_box_get_model (
 							GTK_COMBO_BOX (priv->friends_combo)));
 
 	for (list = followers; list; list = list->next) {
 		user = (TwituxUser *)list->data;
 		gtk_list_store_append (model_followers, &iter);
-		gtk_list_store_set (model_followers, &iter,
+		gtk_list_store_set (model_followers,
+							&iter,
 							0, user->screen_name,
 							-1);
 	}
